********************************************************************************
* This code is used to replicate the findings in Ru, Hong, 2018, Government Credit, a Double-Edged Sword: Evidence from the China Development Bank, Journal of Finance 73.1, 275-316.

* Replicate Table IV Panel A and Table V Panel B (i.e., for SOEs) using 50% random sample. All variables are demeaned by firm ID to condition out firm fixed effects. 
*version 17.0
********************************************************************************

clear
set more off
cd "Please put the data and code under the same directory"
use TableV_SOE.dta,clear

local Llists `"Logworker Logdebt Logsale ROA LogSalesPerWorker"'
global Control `"GDP_Lag Urban_Income_Lag Fiscal_Income_Lag Labor_Lag"'
global Std `"cluster(firm_id)"'
global RHS `"LogLoan_PI"'
global IV `"First Second Third Fourth Fifth Sixth"'

*_I* is for the provice-year fixed effects dummy demeaned at the firm level. 


outreg2 using Table_IV.xls, e(all) excel bdec(3) drop(_I* o._*) replace: reg Logasset $RHS $Control _I*, $Std

foreach LHS of local Llists{
   outreg2 using Table_IV.xls, e(all) excel bdec(3) drop(_I* o._*): reg `LHS' $RHS $Control _I*, $Std
}

**********************************************

outreg2 using Table_V.xls, e(all) excel bdec(3) drop(_I* o._*) replace: ivreg Logasset ($RHS=$IV) $Control _I*, $Std

foreach LHS of local Llists{
   outreg2 using Table_V.xls, e(all) excel bdec(3) drop(_I* o._*): ivreg `LHS' ($RHS=$IV) $Control _I*, $Std
}
